# coding: utf-8

# flake8: noqa

"""
    Signate API

    API for Signate  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from swagger_client.api.default_api import DefaultApi

# import ApiClient
from swagger_client.api_client import ApiClient
from swagger_client.configuration import Configuration
# import models into sdk package
from swagger_client.models.competition import Competition
from swagger_client.models.competitions import Competitions
from swagger_client.models.download import Download
from swagger_client.models.downloads import Downloads
from swagger_client.models.error import Error
from swagger_client.models.file import File
from swagger_client.models.files import Files
from swagger_client.models.submission_option import SubmissionOption
from swagger_client.models.submission_options import SubmissionOptions
from swagger_client.models.success import Success
